@@ -1,5 +1,7 @@
 from __future__ import annotations
-from typing import Callable
+from typing import Callable, TypeVar, Type
+
+T = TypeVar("T", bound="Promulgation")
 
 
 class Promulgation:
@@ -7,10 +9,10 @@ class Promulgation:
     Promulgation.
     """
 
-    listeners: dict[str, list[Callable[[Promulgation], None]]] = {}
+    listeners: dict[str, list[Callable[[T], None]]] = {}
 
     @classmethod
-    def subscribe(cls, listener: Callable[[Promulgation], None]) -> None:
+    def subscribe(cls: Type[T], listener: Callable[[T], None]) -> None:
         """
         Register a function as handler for the given event.
         """
@@ -20,7 +22,7 @@ class Promulgation:
         cls.listeners[cls.__name__].append(listener)
 
     @classmethod
-    def unsubscribe(cls, listener: Callable[[Promulgation], None]) -> None:
+    def unsubscribe(cls: Type[T], listener: Callable[[T], None]) -> None:
         """
         Unregisters a handler for the given event.
         """
